@@ -10,21 +10,21 @@ categorize <- function( dat , categorical=NULL , quant=NULL ,
 	# categorize variables, numbered from lowest to max
 	dfr <- NULL
 	if (! is.null( categorical) ){
-		VV <- length(categorical)	
+		VV <- base::length(categorical)	
 		for (vv in 1:VV){
 			# vv <- 1
 			var.vv <- categorical[vv]    
 			dat.vv <- dat[,var.vv]
-			vals.vv <- base::sort( unique( dat.vv ) )
-			dfr.vv <- data.frame( "index" = vv , "variable" = var.vv ,
-					"column" = which( colnames(dat) == var.vv ) ,
+			vals.vv <- base::sort( base::unique( dat.vv ) )
+			dfr.vv <- base::data.frame( "index" = vv , "variable" = var.vv ,
+					"column" = base::which( colnames(dat) == var.vv ) ,
 					"orig" = vals.vv , 
-					"recode" = seq( lowest , length(vals.vv) -1 + lowest)
+					"recode" = base::seq( lowest , base::length(vals.vv) -1 + lowest)
 								)      
 			dfr <- base::rbind( dfr, dfr.vv )
 			dat2[ , var.vv] <- base::match( dat[,var.vv] , vals.vv ) - 1 + lowest
-					}
-					}
+		}
+	}
 	#**************************
 	# categorize continuous variables into quantiles
 	
@@ -32,7 +32,7 @@ categorize <- function( dat , categorical=NULL , quant=NULL ,
 	
 	if ( ! is.null(quant) ){
 		vars <- names(quant)
-		VV <- length(vars)
+		VV <- base::length(vars)
 	
 		for (vv in 1:VV){
 			# vv <- 1
@@ -47,21 +47,20 @@ categorize <- function( dat , categorical=NULL , quant=NULL ,
 			m1 <- base::cut( dat[,vars.vv]  , breaks = quant.vv )
 			m2 <- base::sort( unique(m1) )
 
-			dfr2.vv <- data.frame( "index" = vv , "variable" = vars.vv ,
-						"column" = which( colnames(dat) == vars.vv ) ,
+			dfr2.vv <- base::data.frame( "index" = vv , "variable" = vars.vv ,
+						"column" = base::which( colnames(dat) == vars.vv ) ,
 						"orig" = m2 , 
-						"recode" = seq( 0 , length(m2) -1 + lowest)
+						"recode" = base::seq( 0 , base::length(m2) -1 + lowest)
 									)  				
 			dfr2 <- base::rbind( dfr2 , dfr2.vv )							
 			dat2[ , vars.vv ] <- base::match( m1 , m2 ) - 1 + lowest		
-				}
-
-						}
+		}
+	}
 						
 	#***************************
 	# OUTPUT
-	res <- list( "data" = dat2 , "categ_design" = dfr ,
+	res <- base::list( "data" = dat2 , "categ_design" = dfr ,
 			"quant_design" = dfr2 )
-	return(res)	
+	base::return(res)	
 }
 #################################################################			
