@@ -27,7 +27,7 @@ nedelsky.sim <- function( theta , b , a=NULL , tau=NULL ){
         tau0 <- as.vector(tau[ii,])
         probs <- nedelsky.irf( Theta , K , b=b0 , a=a0 , tau=tau0 , combis  )$probs
         cprobs <- rowCumsums.sirt(matr=probs)
-        rn1 <- runif(N)
+        rn1 <- stats::runif(N)
         dat[,ii] <- rowIntervalIndex.sirt(matr=cprobs,rn=rn1) - 1
                     }
 	colnames(dat) <- paste0( "I" , 100+1:I )
