@@ -2,7 +2,7 @@
 xxirt_createDiscItem <- function( name , par , est , P , lower=-Inf , 
             upper=Inf , prior=NULL , prior_par1=NULL ,
 			prior_par2 = NULL){
-    res <- list()
+    res <- base::list()
 	res$name <- name
     res$par <- par
     res$est <- est
@@ -12,6 +12,6 @@ xxirt_createDiscItem <- function( name , par , est , P , lower=-Inf ,
     res$prior <- prior
 	res$prior_par1 <- prior_par1
 	res$prior_par2 <- prior_par2
-    class(res) <- "DiscItem"
-    return(res)
-                }
\ No newline at end of file
+    base::class(res) <- "DiscItem"
+    base::return(res)
+}
\ No newline at end of file
