@@ -3,6 +3,6 @@
 xxirt_parTheta_extract_freeParameters <- function( customTheta ){		
 		ind <- customTheta$est
 		p1 <- customTheta$par[ ind ]
-		names(p1) <- names(customTheta$par)[ind]
-		return(p1)
-		}
\ No newline at end of file
+		base::names(p1) <- base::names(customTheta$par)[ind]
+		base::return(p1)
+}
\ No newline at end of file
